[java-identity-provider COMMIT] in /trunk: idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameIDDecoder.ja...

noreply at shibboleth.net noreply at shibboleth.net
Sun Feb 2 12:21:48 EST 2014


Author: rdw
Date: Sun Feb  2 12:21:47 2014
New Revision: 5302

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=5302&view=rev
Log:
IDP-359 Push responsibility for looking inside NameID or NameIdentifier to the specific decoder.  The Action only cares about format (plus whatever else gets injected as a selector.

Added:
    trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameIDDecoder.java   (with props)
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/BaseCryptoTransientDecoder.java
      - copied, changed from r5295, trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/CryptoTransientDecoder.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/BaseTransientDecoder.java
      - copied, changed from r5295, trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/TransientDecoder.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/CryptoTransientNameIDDecoder.java   (with props)
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/DirectNameIDDecoder.java
      - copied, changed from r5295, trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/DirectDecoder.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/TransientNameIDDecoder.java   (with props)
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/nameid/CryptoTransientNameIDDecoderTest.java   (with props)
Modified:
    trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameIdentifierDecoder.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/AbstractSAMLNameCanonicalization.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/CryptoTransientDecoder.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/DirectDecoder.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/NameIDCanonicalization.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/NameIdentifierCanonicalization.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/TransientDecoder.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/attribute/resolver/CryptoTransientIdAttributeDefinitionTest.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/attribute/resolver/TransientIdAttributeDefinitionTest.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/nameid/CryptoTransientDecoderTest.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/nameid/DirectDecoderTest.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/nameid/NameIDCanonicalizationTest.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/nameid/NameIdentifierCanonicalizationTest.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/nameid/TransientDecoderTest.java

Modified: trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameIdentifierDecoder.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameIdentifierDecoder.java?rev=5302&r1=5301&r2=5302&view=diff
==============================================================================
--- trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameIdentifierDecoder.java (original)
+++ trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameIdentifierDecoder.java Sun Feb  2 12:21:47 2014
@@ -22,26 +22,26 @@
 
 import net.shibboleth.idp.authn.SubjectCanonicalizationException;
 
-/**
- * Interface for converting back from value part of a {@link org.opensaml.saml.saml2.core.NameID} or a
- * {@link org.opensaml.saml.saml1.core.NameIdentifier}. Suitable for plugging into both styles of NameIdentifier
- * decoder.
- *
- */
+import org.opensaml.saml.saml1.core.NameIdentifier;
+
+/** Interface for converting back a {@link NameIdentifier} into a single Principal. */
 public interface NameIdentifierDecoder {
 
     /**
      * Decode the provided value, testing or otherwise using either or both of the issuer and requester.
      *
      * @param value the value as extracted from the {@link org.opensaml.saml.saml2.core.NameID} or
      *            {@link org.opensaml.saml.saml1.core.NameIdentifier}
      * @param responderId the entityID of the which issued (and is looking at and responding to) the value
      * @param requesterId the entityID of the which is providing the and which asking for information based on it.
      * @return the principal decoded from the value
      * @throws SubjectCanonicalizationException if match conditions failed.
-     * @throws NameDecoderException if an error occurred during translation.
@@ -22,26 +22,26 @@
 
     /**
-     * Decode the provided value, testing or otherwise using either or both of the issuer and requester.
-     *
-     * @param value the value as extracted from the {@link org.opensaml.saml.saml2.core.NameID} or
+     * Decode the provided {@link NameIdentifier}, testing or otherwise using either or both of the issuer and
+     * requester.
+     * 
+     * @param nameIdentifier {@link org.opensaml.saml.saml2.core.NameID} or
      *            {@link org.opensaml.saml.saml1.core.NameIdentifier}
      * @param responderId the entityID of the which issued (and is looking at and responding to) the value

[... 897 lines stripped ...]


More information about the commits mailing list